@@ -1,7 +1,7 @@
-""" Copy files. """
-
-from pybuildtool.core.task import Task as BaseTask
+""" Copy files.
+"""
 from shutil import copyfile, Error
+from pybuildtool import BaseTask
 
 tool_name = __name__
 
@@ -13,7 +13,8 @@ class Task(BaseTask):
         if len(self.file_in) != 1:
             self.bld.fatal('%s only need one input' % tool_name.capitalize())
         if len(self.file_out) != 1:
-            self.bld.fatal('%s can only have one output' % tool_name.capitalize())
+            self.bld.fatal('%s can only have one output' %\
+                    tool_name.capitalize())
 
         try:
             copyfile(self.file_in[0], self.file_out[0])
